Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1853)

Unified Diff: runtime/vm/object.cc

Issue 1139503002: Move 'dart:profiler' contents into 'dart:developer' and remove 'dart:profiler' (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object.h ('k') | runtime/vm/object_store.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.cc
diff --git a/runtime/vm/object.cc b/runtime/vm/object.cc
index acf260b0e979bed29da4ba958564e47d96074f64..bfa032ae8b995bf7c7638d0a9d72e3b185ccf6cc 100644
--- a/runtime/vm/object.cc
+++ b/runtime/vm/object.cc
@@ -1208,19 +1208,19 @@ RawError* Object::Init(Isolate* isolate) {
RegisterPrivateClass(cls, Symbols::_LinkedHashMap(), lib);
pending_classes.Add(cls);
// Pre-register the profiler library so we can place the vm class
// UserTag there rather than the core library.
- lib = Library::LookupLibrary(Symbols::DartProfiler());
+ lib = Library::LookupLibrary(Symbols::DartDeveloper());
if (lib.IsNull()) {
- lib = Library::NewLibraryHelper(Symbols::DartProfiler(), true);
+ lib = Library::NewLibraryHelper(Symbols::DartDeveloper(), true);
lib.SetLoadRequested();
lib.Register();
- object_store->set_bootstrap_library(ObjectStore::kProfiler, lib);
+ object_store->set_bootstrap_library(ObjectStore::kDeveloper, lib);
}
ASSERT(!lib.IsNull());
- ASSERT(lib.raw() == Library::ProfilerLibrary());
+ ASSERT(lib.raw() == Library::DeveloperLibrary());
- lib = Library::LookupLibrary(Symbols::DartProfiler());
+ lib = Library::LookupLibrary(Symbols::DartDeveloper());
ASSERT(!lib.IsNull());
cls = Class::New<UserTag>();
RegisterPrivateClass(cls, Symbols::_UserTag(), lib);
@@ -9867,11 +9867,6 @@ RawLibrary* Library::NativeWrappersLibrary() {
}
-RawLibrary* Library::ProfilerLibrary() {
- return Isolate::Current()->object_store()->profiler_library();
-}
-
-
RawLibrary* Library::TypedDataLibrary() {
return Isolate::Current()->object_store()->typed_data_library();
}
@@ -10484,12 +10479,12 @@ void Library::CheckFunctionFingerprints() {
POLYMORPHIC_TARGET_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
- all_libs.Add(&Library::ZoneHandle(Library::MathLibrary()));
- MATH_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
+ all_libs.Add(&Library::ZoneHandle(Library::DeveloperLibrary()));
+ DEVELOPER_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
- all_libs.Add(&Library::ZoneHandle(Library::ProfilerLibrary()));
- PROFILER_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
+ all_libs.Add(&Library::ZoneHandle(Library::MathLibrary()));
+ MATH_LIB_INTRINSIC_LIST(CHECK_FINGERPRINTS);
all_libs.Clear();
all_libs.Add(&Library::ZoneHandle(Library::TypedDataLibrary()));
« no previous file with comments | « runtime/vm/object.h ('k') | runtime/vm/object_store.h » ('j') | no next file with comments »
@@ -1208,19 +1208,19 @@ RawError* Object::Init(Isolate* isolate) {
RegisterPrivateClass(cls, Symbols::_LinkedHashMap(), lib);
pending_classes.Add(cls);
- // Pre-register the profiler library so we can place the vm class
+ // Pre-register the developer library so we can place the vm class
// UserTag there rather than the core library.

Powered by Google App Engine
This is Rietveld 408576698